pub enum LocalizedString {
Plain(String),
Localized(HashMap<String, String>),
}Expand description
A localizable text value, matching the WIT localized-string variant.
Plain— a single string in the component’sdefault-language.Localized— a map of BCP 47 language tags to text.
Variants
Plain(String)
A single string assumed to be in the component’s default-language.
Localized(HashMap<String, String>)
Language tag → text map. MUST include the component’s default-language.
Implementations
Sourceimpl LocalizedString
impl LocalizedString
Sourcepub fn new(lang: impl Into<String>, text: impl Into<String>) -> Self
pub fn new(lang: impl Into<String>, text: impl Into<String>) -> Self
Create a localized string with a single language entry.
Sourcepub fn get(&self, lang: &str) -> Option<&str>
pub fn get(&self, lang: &str) -> Option<&str>
Look up text for a specific language tag.
For Plain, always returns the text (it is assumed to match any language).
For Localized, performs exact key lookup.